package flect

import "sync"

var acronymsMoot = &sync.RWMutex{}

var baseAcronyms = map[string]bool{
	"OK":    true,
	"UTF8":  true,
	"HTML":  true,
	"JSON":  true,
	"JWT":   true,
	"ID":    true,
	"UUID":  true,
	"SQL":   true,
	"ACK":   true,
	"ACL":   true,
	"ADSL":  true,
	"AES":   true,
	"ANSI":  true,
	"API":   true,
	"ARP":   true,
	"ATM":   true,
	"BGP":   true,
	"BSS":   true,
	"CCITT": true,
	"CHAP":  true,
	"CIDR":  true,
	"CIR":   true,
	"CLI":   true,
	"CPE":   true,
	"CPU":   true,
	"CRC":   true,
	"CRT":   true,
	"CSMA":  true,
	"CMOS":  true,
	"DCE":   true,
	"DEC":   true,
	"DES":   true,
	"DHCP":  true,
	"DNS":   true,
	"DRAM":  true,
	"DSL":   true,
	"DSLAM": true,
	"DTE":   true,
	"DMI":   true,
	"EHA":   true,
	"EIA":   true,
	"EIGRP": true,
	"EOF":   true,
	"ESS":   true,
	"FCC":   true,
	"FCS":   true,
	"FDDI":  true,
	"FTP":   true,
	"GBIC":  true,
	"gbps":  true,
	"GEPOF": true,
	"HDLC":  true,
	"HTTP":  true,
	"HTTPS": true,
	"IANA":  true,
	"ICMP":  true,
	"IDF":   true,
	"IDS":   true,
	"IEEE":  true,
	"IETF":  true,
	"IMAP":  true,
	"IP":    true,
	"IPS":   true,
	"ISDN":  true,
	"ISP":   true,
	"kbps":  true,
	"LACP":  true,
	"LAN":   true,
	"LAPB":  true,
	"LAPF":  true,
	"LLC":   true,
	"MAC":   true,
	"Mbps":  true,
	"MC":    true,
	"MDF":   true,
	"MIB":   true,
	"MoCA":  true,
	"MPLS":  true,
	"MTU":   true,
	"NAC":   true,
	"NAT":   true,
	"NBMA":  true,
	"NIC":   true,
	"NRZ":   true,
	"NRZI":  true,
	"NVRAM": true,
	"OSI":   true,
	"OSPF":  true,
	"OUI":   true,
	"PAP":   true,
	"PAT":   true,
	"PC":    true,
	"PIM":   true,
	"PCM":   true,
	"PDU":   true,
	"POP3":  true,
	"POTS":  true,
	"PPP":   true,
	"PPTP":  true,
	"PTT":   true,
	"PVST":  true,
	"RAM":   true,
	"RARP":  true,
	"RFC":   true,
	"RIP":   true,
	"RLL":   true,
	"ROM":   true,
	"RSTP":  true,
	"RTP":   true,
	"RCP":   true,
	"SDLC":  true,
	"SFD":   true,
	"SFP":   true,
	"SLARP": true,
	"SLIP":  true,
	"SMTP":  true,
	"SNA":   true,
	"SNAP":  true,
	"SNMP":  true,
	"SOF":   true,
	"SRAM":  true,
	"SSH":   true,
	"SSID":  true,
	"STP":   true,
	"SYN":   true,
	"TDM":   true,
	"TFTP":  true,
	"TIA":   true,
	"TOFU":  true,
	"UDP":   true,
	"URL":   true,
	"URI":   true,
	"USB":   true,
	"UTP":   true,
	"VC":    true,
	"VLAN":  true,
	"VLSM":  true,
	"VPN":   true,
	"W3C":   true,
	"WAN":   true,
	"WEP":   true,
	"WiFi":  true,
	"WPA":   true,
	"WWW":   true,
}
